@@ -14,13 +14,13 @@ def write_dotenv(env, file=".env"):
         for i in env:
             f.write(f'{i}={env[i]}\n')
 
-def to_print_dict(dic:dict,spaces = 4):
+def to_print_dict(dic:dict, spaces = 4):
     """
     @ make the dict a key: value table string
     """
     ret = ''
     for i in dic:
-        ret = ret + f"""{i}: {dic[i]}\n{spaces*' '}"""
+        ret = ret + '\n' + f"{i}: {dic[i]}"
     return ret
 
 def print_dict(dic:dict):
@@ -38,11 +38,14 @@ def sample(vec):
     """
     return vec[randint(len(vec))]
 
-def to_print_list(ls):
+def to_print_list(ls, skip_rows = False):
     """just remove [] from list to print it"""
     ret = ''
+    skip = None
+    if skip_rows:
+        skip = '\n'
     for i in ls:
-        ret=ret+f'{i},'
+        ret=ret+f'{i},{skip}'
     return ret[:-1]
 
 def print_list(ls):
